@@ -35,6 +35,7 @@ class PiusSigner(object):
   GPG_PROGRESS = '[GNUPG:] PROGRESS'
   GPG_PINENTRY_LAUNCHED = '[GNUPG:] PINENTRY_LAUNCHED'
   GPG_KEY_CONSIDERED = '[GNUPG:] KEY_CONSIDERED'
+  GPG_WARN_VERSION = '[GNUPG:] WARNING server_version_mismatch'
 
   def __init__(self, signer, force_signer, mode, keyring, gpg_path, tmpdir,
                outdir, encrypt_outfiles, mail, mailer, verbose, sort_keyring,
@@ -479,28 +480,35 @@ class PiusSigner(object):
 
   def export_clean_key(self, key):
     '''Export clean key from the users' KeyID.'''
-    debug('exporting %s' % key)
-    # We have to export our own public key as well
-    keys_to_export = [key, self.signer]
-    path = self._tmpfile_path('%s.asc' % key)
-    self._export_key(self.keyring, keys_to_export, path)
+    # Export our public key and the given public key
+    for x in [self.signer, key]:
+       debug('exporting %s' % x)
+       path = self._tmpfile_path('%s.asc' % x)
+       self._export_key(self.keyring, [x], path)
 
   def clean_clean_key(self, key):
     '''Delete the "clean" unsigned key which we exported temporarily.'''
-    path = self._tmpfile_path('%s.asc' % key)
-    clean_files([path])
+    # Remove the temporary exports of the public keys
+    paths = [self._tmpfile_path('%s.asc' % x) for x in [self.signer, key]]
+    clean_files(paths)
 
   def import_clean_key(self, key):
-    '''Import the clean key we expoerted in export_clean_key() to our temp
+    '''Import the clean key we exported in export_clean_key() to our temp
     keyring.'''
-    path = self._tmpfile_path('%s.asc' %  key)
-    cmd = [self.gpg] + self.gpg_base_opts + self.gpg_quiet_opts + [
-        '--no-default-keyring',
-        '--keyring', self.tmp_keyring,
-        '--import-options', 'import-minimal',
-        '--import', path,
-    ]
-    self._run_and_check_status(cmd)
+    # Import the export of our public key and the given public key
+    for x in [self.signer, key]:
+        debug('importing %s' % x)
+        import_opts = ['import-minimal']
+        if x == self.signer:
+            import_opts.append('keep-ownertrust')
+        path = self._tmpfile_path('%s.asc' %  x)
+        cmd = [self.gpg] + self.gpg_base_opts + self.gpg_quiet_opts + [
+            '--no-default-keyring',
+            '--keyring', self.tmp_keyring,
+            '--import-options', ','.join(import_opts),
+            '--import', path,
+        ]
+        self._run_and_check_status(cmd)
 
   def policy_opts(self):
     if self.policy_url:
@@ -896,7 +904,8 @@ class PiusSigner(object):
             PiusSigner.GPG_SIG_BEG in line or
             PiusSigner.GPG_SIG_CREATED in line or
             PiusSigner.GPG_PROGRESS in line or
-            PiusSigner.GPG_PINENTRY_LAUNCHED in line):
+            PiusSigner.GPG_PINENTRY_LAUNCHED in line or
+            PiusSigner.GPG_WARN_VERSION):
         debug('Got skippable stuff')
         continue
       else:
